TensorInfo

Struct TensorInfo 

pub struct TensorInfo {
    pub name: String,
    pub shape: Vec<i32>,
    pub dtype: DataType,
    pub format: DataFormat,
}
Information about a tensor’s shape and type.

Fields

name: String

Name of the tensor (may be empty)

shape: Vec<i32>

Shape of the tensor (dimensions)

dtype: DataType

Data type of tensor elements

format: DataFormat

Data format (layout)

Implementations

Source

impl TensorInfo

pub fn element_count(&self) -> i32

Get the total number of elements in the tensor.

pub fn byte_size(&self) -> usize

Get the size in bytes of the tensor data.

Source

impl TensorInfo

pub fn dtype(&self) -> DataType

Get the data type.