pub trait TensorData:
Default
+ Clone
+ Copy
+ 'static {
// Required method
fn dtype() -> DataType;
}Expand description
Trait for types that can be stored in a tensor.
This trait is implemented for primitive numeric types that MNN supports.
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.